; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a ladder plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "ladder_plot.pro" and run it like this::
;       IDL> .RUN ladder_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 23 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Ladder_Plot
 
   ; Example random data. Normally passed into the program as a positional parameter.
   data_1 = cgDemoData(17)
   data_2 = cgScaleVector(cgDemoData(17), -10, 10)
   thick = (!D.Name EQ 'PS') ? 4 : 2
   
   ; Draw the bottom plot without a top axis (XSTYLE=8).
   cgPlot, data_1, XStyle=8, Position=[0.15, 0.15, 0.90, 0.50], $
      XTitle='Time', YTitle='Signal', Color='red', Thick=thick
      
   ; Draw the top plot without a top axis. Bottom of this plot is top of 
   ; first plot. Suppress X tick formatting.
   cgPlot, data_2, XStyle=8, Position=[0.15, 0.52, 0.90, 0.90], $
      /NoErase, XTickformat='(A1)', YTitle='Offset', Color='blu7', Thick=thick
      
   ; Add the top axis.
   cgAxis, !X.CRange[1], !Y.CRange[1], XRange=!X.CRANGE, XAxis=1
   
   ; Repair some of the damage to the axes.
   cgPlots, [0.15, 0.15], [0.50, 0.52], /Normal ; Fix left axis.
   cgPlots, [0.90, 0.90], [0.50, 0.52], /Normal ; Fix right axis.
      
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Ladder_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Ladder_Plot', WBackground='White', $
     WTitle='Ladder Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'ladder_plot.ps'
  Ladder_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'ladder_plot.ps', /PNG, Width=600

END